@@ -17,11 +17,8 @@ from six import moves
 import sqlalchemy
 from sqlalchemy.orm.properties import RelationshipProperty
 
+from tacker._i18n import _
 from tacker.common import exceptions as n_exc
-from tacker.openstack.common import log as logging
-
-
-LOG = logging.getLogger(__name__)
 
 
 def paginate_query(query, model, limit, sorts, marker_obj=None):
